# -*- coding: utf-8 -*-
# Part of Odoo. See LICENSE file for full copyright and licensing details.

{
    'name': 'Mass mailing sms on sale orders',
    'category': 'Marketing/Email Marketing',
    'version': '1.0',
    'summary': 'Add sale order info on mass mailing sms',
    'description': """Mass mailing sms on sale orders""",
    'depends': ['mass_mailing_sale', 'mass_mailing_sms'],
    'auto_install': True,
    'author': 'Odoo S.A.',
    'license': 'LGPL-3',
}
